Karaage 3
=========

**Cluster account management tool.**

.. contents :: Table of Contents

Overview
--------

Karaage manages users and projects in a cluster and can store the data in
various backends.


Documentation
-------------

Mailing list: `<http://lists.vpac.org/cgi-bin/mailman/listinfo/karaage>`_

Old gerrit code review tool (not used anymore): `<https://code.vpac.org/gerrit>`_

Karaage 2.7.x: <http://karaage.readthedocs.org/en/2.7.stable/>`_.

Karaage 3.x User documentation:
`<http://karaage.readthedocs.org/projects/karaage-user/en/latest/>`_

Karaage 3.x Programmer documentation:
`<http://karaage.readthedocs.org/projects/karaage-programmer/en/latest/>`_

Karaage 3.x Admin documentation: `<http://karaage.readthedocs.org/en/latest/>`_

Software requirements specification:
`<http://karaage.readthedocs.org/projects/karaage-srs/en/latest/>`_



Components
----------

Prior to Karaage 3.1.11, the various Karaage modules had been in seperate
repositories. They have now been brought together into one repo.

These modules are:

- karaage-applications (also see `Karaage 3 karaage-applications
  <https://github.com/Karaage-Cluster/karaage-applications>`_)
- karaage-cluster-tools  (also see `Karaage 3 karaage-cluster-tools
  <https://github.com/Karaage-Cluster/karaage-cluster-tools>`_)
- karaage-software (also see `Karaage 3 karaage-software
  <https://github.com/Karaage-Cluster/karaage-software>`_)
- karaage-usage (also see `Karaage 3 karaage-usage
  <https://github.com/Karaage-Cluster/karaage-usage>`_)


Plugins
-------

karaage-usage
^^^^^^^^^^^^^

.. todo:: Write paragraph about what the usage plugin does.

The karaage-usage plugin provides monitoring of usage information.

karaage-applications
^^^^^^^^^^^^^^^^^^^^

This plugin allows users to self register accounts with Karaage.


karaage-software
^^^^^^^^^^^^^^^^

.. todo:: Write paragraph about what the software plugin does.


Contact
-------

The lead developer for Karaage 3 is `Brian May
<mailto:"brian@v3.org.au">`_.
